@@ -235,8 +235,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -783,5 +782,9 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("CloudBuildGrpcTransport",)
